.. -*- coding: utf-8 -*-

.. _Part1:

-----------------------------------
Part I - Introduction to *CubicWeb*
-----------------------------------

This first part of the book offers different reading path to
discover the *CubicWeb* framework, provides a tutorial to get a quick
overview of its features and lists its key concepts.


.. toctree::
   :maxdepth: 2

   book-map
   history
   concepts/index
   tutorial/index
